<?php

namespace Bixo\Accounts\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Accounts\Models\Accounts;

class AccountsPolicy
{

    /**
     * Determine if the given user can view the accounts.
     *
     * @param UserPolicy $user
     * @param Accounts $accounts
     *
     * @return bool
     */
    public function view(UserPolicy $user, Accounts $accounts)
    {
        if ($user->canDo('accounts.accounts.view') && $user->isAdmin()) {
            return true;
        }

        return $accounts->user_id == user_id() && $accounts->user_type == user_type();
    }

    /**
     * Determine if the given user can create a accounts.
     *
     * @param UserPolicy $user
     * @param Accounts $accounts
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('accounts.accounts.create');
    }

    /**
     * Determine if the given user can update the given accounts.
     *
     * @param UserPolicy $user
     * @param Accounts $accounts
     *
     * @return bool
     */
    public function update(UserPolicy $user, Accounts $accounts)
    {
        if ($user->canDo('accounts.accounts.edit') && $user->isAdmin()) {
            return true;
        }

        return $accounts->user_id == user_id() && $accounts->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given accounts.
     *
     * @param UserPolicy $user
     * @param Accounts $accounts
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Accounts $accounts)
    {
        return $accounts->user_id == user_id() && $accounts->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given accounts.
     *
     * @param UserPolicy $user
     * @param Accounts $accounts
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Accounts $accounts)
    {
        if ($user->canDo('accounts.accounts.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given accounts.
     *
     * @param UserPolicy $user
     * @param Accounts $accounts
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Accounts $accounts)
    {
        if ($user->canDo('accounts.accounts.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
